# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import grpc_auth_service.oauth_service_pb2 as oauth__service__pb2


class GoogleOAuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProviderLoginURL = channel.unary_unary(
                '/GoogleOAuth/GetProviderLoginURL',
                request_serializer=oauth__service__pb2.GetProviderLoginURLRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.GetProviderLoginURLResponse.FromString,
                )
        self.Login = channel.unary_unary(
                '/GoogleOAuth/Login',
                request_serializer=oauth__service__pb2.OAuthLoginRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.OAuthLoginResponse.FromString,
                )
        self.GetProviderLoginURLForAttach = channel.unary_unary(
                '/GoogleOAuth/GetProviderLoginURLForAttach',
                request_serializer=oauth__service__pb2.GetProviderLoginURLForAttachRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.GetProviderLoginURLForAttachResponse.FromString,
                )
        self.AttachAccountToUser = channel.unary_unary(
                '/GoogleOAuth/AttachAccountToUser',
                request_serializer=oauth__service__pb2.AttachAccountToUserRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.AttachAccountToUserResponse.FromString,
                )
        self.DetachAccountFromUser = channel.unary_unary(
                '/GoogleOAuth/DetachAccountFromUser',
                request_serializer=oauth__service__pb2.DetachAccountFromUserRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.DetachAccountFromUserResponse.FromString,
                )


class GoogleOAuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProviderLoginURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProviderLoginURLForAttach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachAccountToUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachAccountFromUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GoogleOAuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProviderLoginURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderLoginURL,
                    request_deserializer=oauth__service__pb2.GetProviderLoginURLRequest.FromString,
                    response_serializer=oauth__service__pb2.GetProviderLoginURLResponse.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=oauth__service__pb2.OAuthLoginRequest.FromString,
                    response_serializer=oauth__service__pb2.OAuthLoginResponse.SerializeToString,
            ),
            'GetProviderLoginURLForAttach': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderLoginURLForAttach,
                    request_deserializer=oauth__service__pb2.GetProviderLoginURLForAttachRequest.FromString,
                    response_serializer=oauth__service__pb2.GetProviderLoginURLForAttachResponse.SerializeToString,
            ),
            'AttachAccountToUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachAccountToUser,
                    request_deserializer=oauth__service__pb2.AttachAccountToUserRequest.FromString,
                    response_serializer=oauth__service__pb2.AttachAccountToUserResponse.SerializeToString,
            ),
            'DetachAccountFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachAccountFromUser,
                    request_deserializer=oauth__service__pb2.DetachAccountFromUserRequest.FromString,
                    response_serializer=oauth__service__pb2.DetachAccountFromUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'GoogleOAuth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GoogleOAuth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProviderLoginURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GoogleOAuth/GetProviderLoginURL',
            oauth__service__pb2.GetProviderLoginURLRequest.SerializeToString,
            oauth__service__pb2.GetProviderLoginURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GoogleOAuth/Login',
            oauth__service__pb2.OAuthLoginRequest.SerializeToString,
            oauth__service__pb2.OAuthLoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProviderLoginURLForAttach(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GoogleOAuth/GetProviderLoginURLForAttach',
            oauth__service__pb2.GetProviderLoginURLForAttachRequest.SerializeToString,
            oauth__service__pb2.GetProviderLoginURLForAttachResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachAccountToUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GoogleOAuth/AttachAccountToUser',
            oauth__service__pb2.AttachAccountToUserRequest.SerializeToString,
            oauth__service__pb2.AttachAccountToUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachAccountFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GoogleOAuth/DetachAccountFromUser',
            oauth__service__pb2.DetachAccountFromUserRequest.SerializeToString,
            oauth__service__pb2.DetachAccountFromUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class YandexOAuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProviderLoginURL = channel.unary_unary(
                '/YandexOAuth/GetProviderLoginURL',
                request_serializer=oauth__service__pb2.GetProviderLoginURLRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.GetProviderLoginURLResponse.FromString,
                )
        self.Login = channel.unary_unary(
                '/YandexOAuth/Login',
                request_serializer=oauth__service__pb2.OAuthLoginRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.OAuthLoginResponse.FromString,
                )
        self.GetProviderLoginURLForAttach = channel.unary_unary(
                '/YandexOAuth/GetProviderLoginURLForAttach',
                request_serializer=oauth__service__pb2.GetProviderLoginURLForAttachRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.GetProviderLoginURLForAttachResponse.FromString,
                )
        self.AttachAccountToUser = channel.unary_unary(
                '/YandexOAuth/AttachAccountToUser',
                request_serializer=oauth__service__pb2.AttachAccountToUserRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.AttachAccountToUserResponse.FromString,
                )
        self.DetachAccountFromUser = channel.unary_unary(
                '/YandexOAuth/DetachAccountFromUser',
                request_serializer=oauth__service__pb2.DetachAccountFromUserRequest.SerializeToString,
                response_deserializer=oauth__service__pb2.DetachAccountFromUserResponse.FromString,
                )


class YandexOAuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProviderLoginURL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProviderLoginURLForAttach(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachAccountToUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachAccountFromUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_YandexOAuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetProviderLoginURL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderLoginURL,
                    request_deserializer=oauth__service__pb2.GetProviderLoginURLRequest.FromString,
                    response_serializer=oauth__service__pb2.GetProviderLoginURLResponse.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=oauth__service__pb2.OAuthLoginRequest.FromString,
                    response_serializer=oauth__service__pb2.OAuthLoginResponse.SerializeToString,
            ),
            'GetProviderLoginURLForAttach': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProviderLoginURLForAttach,
                    request_deserializer=oauth__service__pb2.GetProviderLoginURLForAttachRequest.FromString,
                    response_serializer=oauth__service__pb2.GetProviderLoginURLForAttachResponse.SerializeToString,
            ),
            'AttachAccountToUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachAccountToUser,
                    request_deserializer=oauth__service__pb2.AttachAccountToUserRequest.FromString,
                    response_serializer=oauth__service__pb2.AttachAccountToUserResponse.SerializeToString,
            ),
            'DetachAccountFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachAccountFromUser,
                    request_deserializer=oauth__service__pb2.DetachAccountFromUserRequest.FromString,
                    response_serializer=oauth__service__pb2.DetachAccountFromUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'YandexOAuth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class YandexOAuth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProviderLoginURL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/YandexOAuth/GetProviderLoginURL',
            oauth__service__pb2.GetProviderLoginURLRequest.SerializeToString,
            oauth__service__pb2.GetProviderLoginURLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/YandexOAuth/Login',
            oauth__service__pb2.OAuthLoginRequest.SerializeToString,
            oauth__service__pb2.OAuthLoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProviderLoginURLForAttach(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/YandexOAuth/GetProviderLoginURLForAttach',
            oauth__service__pb2.GetProviderLoginURLForAttachRequest.SerializeToString,
            oauth__service__pb2.GetProviderLoginURLForAttachResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachAccountToUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/YandexOAuth/AttachAccountToUser',
            oauth__service__pb2.AttachAccountToUserRequest.SerializeToString,
            oauth__service__pb2.AttachAccountToUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachAccountFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/YandexOAuth/DetachAccountFromUser',
            oauth__service__pb2.DetachAccountFromUserRequest.SerializeToString,
            oauth__service__pb2.DetachAccountFromUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnyUserOAuthProviderAccount(_message.Message):
    __slots__ = ["account_id", "provider"]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    provider: str
    def __init__(self, provider: _Optional[str] = ..., account_id: _Optional[str] = ...) -> None: ...

class CheckAccessRequest(_message.Message):
    __slots__ = ["access_token", "inquiry"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    INQUIRY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    inquiry: str
    def __init__(self, access_token: _Optional[str] = ..., inquiry: _Optional[str] = ...) -> None: ...

class CheckAccessResponse(_message.Message):
    __slots__ = ["has_access"]
    HAS_ACCESS_FIELD_NUMBER: _ClassVar[int]
    has_access: bool
    def __init__(self, has_access: bool = ...) -> None: ...

class CreatePolicyRequest(_message.Message):
    __slots__ = ["access_token", "policy"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    policy: str
    def __init__(self, access_token: _Optional[str] = ..., policy: _Optional[str] = ...) -> None: ...

class CreatePolicyResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeletePolicyRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class DeletePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetPolicyListRequest(_message.Message):
    __slots__ = ["access_token", "page_number", "page_size"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    page_number: int
    page_size: int
    def __init__(self, access_token: _Optional[str] = ..., page_number: _Optional[int] = ..., page_size: _Optional[int] = ...) -> None: ...

class GetPolicyListResponse(_message.Message):
    __slots__ = ["next_page", "policy", "prev_page", "total_count", "total_pages"]
    NEXT_PAGE_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    next_page: int
    policy: _containers.RepeatedScalarFieldContainer[str]
    prev_page: int
    total_count: int
    total_pages: int
    def __init__(self, policy: _Optional[_Iterable[str]] = ..., total_count: _Optional[int] = ..., total_pages: _Optional[int] = ..., prev_page: _Optional[int] = ..., next_page: _Optional[int] = ...) -> None: ...

class GetPolicyRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetPolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: str
    def __init__(self, policy: _Optional[str] = ...) -> None: ...

class GetUserListRequest(_message.Message):
    __slots__ = ["access_token", "page_number", "page_size"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    page_number: int
    page_size: int
    def __init__(self, access_token: _Optional[str] = ..., page_number: _Optional[int] = ..., page_size: _Optional[int] = ...) -> None: ...

class GetUserListResponse(_message.Message):
    __slots__ = ["next_page", "prev_page", "results", "total_count", "total_pages"]
    NEXT_PAGE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    next_page: int
    prev_page: int
    results: _containers.RepeatedCompositeFieldContainer[UserInList]
    total_count: int
    total_pages: int
    def __init__(self, results: _Optional[_Iterable[_Union[UserInList, _Mapping]]] = ..., total_count: _Optional[int] = ..., total_pages: _Optional[int] = ..., prev_page: _Optional[int] = ..., next_page: _Optional[int] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ["access_token", "id"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ["email", "id", "is_active", "is_superuser", "oauth_accounts"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    OAUTH_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    is_active: bool
    is_superuser: bool
    oauth_accounts: _containers.RepeatedCompositeFieldContainer[AnyUserOAuthProviderAccount]
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ..., is_active: bool = ..., is_superuser: bool = ..., oauth_accounts: _Optional[_Iterable[_Union[AnyUserOAuthProviderAccount, _Mapping]]] = ...) -> None: ...

class UpdatePolicyRequest(_message.Message):
    __slots__ = ["access_token", "id", "policy"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    id: str
    policy: str
    def __init__(self, access_token: _Optional[str] = ..., id: _Optional[str] = ..., policy: _Optional[str] = ...) -> None: ...

class UpdatePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UserInList(_message.Message):
    __slots__ = ["email", "id", "is_active", "is_superuser"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    is_active: bool
    is_superuser: bool
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ..., is_active: bool = ..., is_superuser: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12user_service.proto\"4\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"/\n\x12\x43reateUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"Z\n\x1aGetUserLoginHistoryRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"X\n\x10UserLoginHistory\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x12\n\nuser_agent\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\"\xb7\x01\n\x1bGetUserLoginHistoryResponse\x12\"\n\x07results\x18\x01 \x03(\x0b\x32\x11.UserLoginHistory\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\"(\n\x10GetUserMeRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"@\n\x18UserOAuthProviderAccount\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"U\n\x11GetUserMeResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x31\n\x0eoauth_accounts\x18\x02 \x03(\x0b\x32\x19.UserOAuthProviderAccount2\xbb\x01\n\x04User\x12\x31\n\x06\x43reate\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12L\n\x0fGetLoginHistory\x12\x1b.GetUserLoginHistoryRequest\x1a\x1c.GetUserLoginHistoryResponse\x12\x32\n\tGetUserMe\x12\x11.GetUserMeRequest\x1a\x12.GetUserMeResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEUSERREQUEST._serialized_start=22
  _CREATEUSERREQUEST._serialized_end=74
  _CREATEUSERRESPONSE._serialized_start=76
  _CREATEUSERRESPONSE._serialized_end=123
  _GETUSERLOGINHISTORYREQUEST._serialized_start=125
  _GETUSERLOGINHISTORYREQUEST._serialized_end=215
  _USERLOGINHISTORY._serialized_start=217
  _USERLOGINHISTORY._serialized_end=305
  _GETUSERLOGINHISTORYRESPONSE._serialized_start=308
  _GETUSERLOGINHISTORYRESPONSE._serialized_end=491
  _GETUSERMEREQUEST._serialized_start=493
  _GETUSERMEREQUEST._serialized_end=533
  _USEROAUTHPROVIDERACCOUNT._serialized_start=535
  _USEROAUTHPROVIDERACCOUNT._serialized_end=599
  _GETUSERMERESPONSE._serialized_start=601
  _GETUSERMERESPONSE._serialized_end=686
  _USER._serialized_start=689
  _USER._serialized_end=876
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import grpc_auth_service.role_service_pb2 as role__service__pb2


class AdminRoleStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUser = channel.unary_unary(
                '/AdminRole/GetUser',
                request_serializer=role__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=role__service__pb2.GetUserResponse.FromString,
                )
        self.GetUserList = channel.unary_unary(
                '/AdminRole/GetUserList',
                request_serializer=role__service__pb2.GetUserListRequest.SerializeToString,
                response_deserializer=role__service__pb2.GetUserListResponse.FromString,
                )
        self.CreatePolicy = channel.unary_unary(
                '/AdminRole/CreatePolicy',
                request_serializer=role__service__pb2.CreatePolicyRequest.SerializeToString,
                response_deserializer=role__service__pb2.CreatePolicyResponse.FromString,
                )
        self.UpdatePolicy = channel.unary_unary(
                '/AdminRole/UpdatePolicy',
                request_serializer=role__service__pb2.UpdatePolicyRequest.SerializeToString,
                response_deserializer=role__service__pb2.UpdatePolicyResponse.FromString,
                )
        self.DeletePolicy = channel.unary_unary(
                '/AdminRole/DeletePolicy',
                request_serializer=role__service__pb2.DeletePolicyRequest.SerializeToString,
                response_deserializer=role__service__pb2.DeletePolicyResponse.FromString,
                )
        self.GetPolicy = channel.unary_unary(
                '/AdminRole/GetPolicy',
                request_serializer=role__service__pb2.GetPolicyRequest.SerializeToString,
                response_deserializer=role__service__pb2.GetPolicyResponse.FromString,
                )
        self.GetPolicyList = channel.unary_unary(
                '/AdminRole/GetPolicyList',
                request_serializer=role__service__pb2.GetPolicyListRequest.SerializeToString,
                response_deserializer=role__service__pb2.GetPolicyListResponse.FromString,
                )
        self.CheckAccess = channel.unary_unary(
                '/AdminRole/CheckAccess',
                request_serializer=role__service__pb2.CheckAccessRequest.SerializeToString,
                response_deserializer=role__service__pb2.CheckAccessResponse.FromString,
                )


class AdminRoleServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicyList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAccess(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminRoleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=role__service__pb2.GetUserRequest.FromString,
                    response_serializer=role__service__pb2.GetUserResponse.SerializeToString,
            ),
            'GetUserList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserList,
                    request_deserializer=role__service__pb2.GetUserListRequest.FromString,
                    response_serializer=role__service__pb2.GetUserListResponse.SerializeToString,
            ),
            'CreatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicy,
                    request_deserializer=role__service__pb2.CreatePolicyRequest.FromString,
                    response_serializer=role__service__pb2.CreatePolicyResponse.SerializeToString,
            ),
            'UpdatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePolicy,
                    request_deserializer=role__service__pb2.UpdatePolicyRequest.FromString,
                    response_serializer=role__service__pb2.UpdatePolicyResponse.SerializeToString,
            ),
            'DeletePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePolicy,
                    request_deserializer=role__service__pb2.DeletePolicyRequest.FromString,
                    response_serializer=role__service__pb2.DeletePolicyResponse.SerializeToString,
            ),
            'GetPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicy,
                    request_deserializer=role__service__pb2.GetPolicyRequest.FromString,
                    response_serializer=role__service__pb2.GetPolicyResponse.SerializeToString,
            ),
            'GetPolicyList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicyList,
                    request_deserializer=role__service__pb2.GetPolicyListRequest.FromString,
                    response_serializer=role__service__pb2.GetPolicyListResponse.SerializeToString,
            ),
            'CheckAccess': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAccess,
                    request_deserializer=role__service__pb2.CheckAccessRequest.FromString,
                    response_serializer=role__service__pb2.CheckAccessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AdminRole', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdminRole(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/GetUser',
            role__service__pb2.GetUserRequest.SerializeToString,
            role__service__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/GetUserList',
            role__service__pb2.GetUserListRequest.SerializeToString,
            role__service__pb2.GetUserListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/CreatePolicy',
            role__service__pb2.CreatePolicyRequest.SerializeToString,
            role__service__pb2.CreatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/UpdatePolicy',
            role__service__pb2.UpdatePolicyRequest.SerializeToString,
            role__service__pb2.UpdatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/DeletePolicy',
            role__service__pb2.DeletePolicyRequest.SerializeToString,
            role__service__pb2.DeletePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/GetPolicy',
            role__service__pb2.GetPolicyRequest.SerializeToString,
            role__service__pb2.GetPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicyList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/GetPolicyList',
            role__service__pb2.GetPolicyListRequest.SerializeToString,
            role__service__pb2.GetPolicyListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAccess(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AdminRole/CheckAccess',
            role__service__pb2.CheckAccessRequest.SerializeToString,
            role__service__pb2.CheckAccessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import grpc_auth_service.auth_service_pb2 as auth__service__pb2


class AuthStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
                '/Auth/Login',
                request_serializer=auth__service__pb2.LoginRequest.SerializeToString,
                response_deserializer=auth__service__pb2.LoginResponse.FromString,
                )
        self.RefreshToken = channel.unary_unary(
                '/Auth/RefreshToken',
                request_serializer=auth__service__pb2.RefreshTokenRequest.SerializeToString,
                response_deserializer=auth__service__pb2.RefreshTokenResponse.FromString,
                )
        self.Logout = channel.unary_unary(
                '/Auth/Logout',
                request_serializer=auth__service__pb2.LogoutRequest.SerializeToString,
                response_deserializer=auth__service__pb2.LogoutResponse.FromString,
                )
        self.LogoutOther = channel.unary_unary(
                '/Auth/LogoutOther',
                request_serializer=auth__service__pb2.LogoutOtherRequest.SerializeToString,
                response_deserializer=auth__service__pb2.LogoutOtherResponse.FromString,
                )
        self.UpdatePassword = channel.unary_unary(
                '/Auth/UpdatePassword',
                request_serializer=auth__service__pb2.UpdateUserPasswordRequest.SerializeToString,
                response_deserializer=auth__service__pb2.UpdateUserPasswordResponse.FromString,
                )
        self.UpdateEmail = channel.unary_unary(
                '/Auth/UpdateEmail',
                request_serializer=auth__service__pb2.UpdateUserEmailRequest.SerializeToString,
                response_deserializer=auth__service__pb2.UpdateUserEmailResponse.FromString,
                )
        self.CheckToken = channel.unary_unary(
                '/Auth/CheckToken',
                request_serializer=auth__service__pb2.CheckTokenRequest.SerializeToString,
                response_deserializer=auth__service__pb2.CheckTokenResponse.FromString,
                )


class AuthServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogoutOther(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth__service__pb2.LoginRequest.FromString,
                    response_serializer=auth__service__pb2.LoginResponse.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=auth__service__pb2.RefreshTokenRequest.FromString,
                    response_serializer=auth__service__pb2.RefreshTokenResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=auth__service__pb2.LogoutRequest.FromString,
                    response_serializer=auth__service__pb2.LogoutResponse.SerializeToString,
            ),
            'LogoutOther': grpc.unary_unary_rpc_method_handler(
                    servicer.LogoutOther,
                    request_deserializer=auth__service__pb2.LogoutOtherRequest.FromString,
                    response_serializer=auth__service__pb2.LogoutOtherResponse.SerializeToString,
            ),
            'UpdatePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePassword,
                    request_deserializer=auth__service__pb2.UpdateUserPasswordRequest.FromString,
                    response_serializer=auth__service__pb2.UpdateUserPasswordResponse.SerializeToString,
            ),
            'UpdateEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEmail,
                    request_deserializer=auth__service__pb2.UpdateUserEmailRequest.FromString,
                    response_serializer=auth__service__pb2.UpdateUserEmailResponse.SerializeToString,
            ),
            'CheckToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckToken,
                    request_deserializer=auth__service__pb2.CheckTokenRequest.FromString,
                    response_serializer=auth__service__pb2.CheckTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Auth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Auth(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/Login',
            auth__service__pb2.LoginRequest.SerializeToString,
            auth__service__pb2.LoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/RefreshToken',
            auth__service__pb2.RefreshTokenRequest.SerializeToString,
            auth__service__pb2.RefreshTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/Logout',
            auth__service__pb2.LogoutRequest.SerializeToString,
            auth__service__pb2.LogoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogoutOther(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/LogoutOther',
            auth__service__pb2.LogoutOtherRequest.SerializeToString,
            auth__service__pb2.LogoutOtherResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/UpdatePassword',
            auth__service__pb2.UpdateUserPasswordRequest.SerializeToString,
            auth__service__pb2.UpdateUserPasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/UpdateEmail',
            auth__service__pb2.UpdateUserEmailRequest.SerializeToString,
            auth__service__pb2.UpdateUserEmailResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Auth/CheckToken',
            auth__service__pb2.CheckTokenRequest.SerializeToString,
            auth__service__pb2.CheckTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



class Constants:
    RESOURCE: str = "resource"
    RESOURCE_PATH: str = "path"
    RESOURCE_SERVICE: str = "service"
    RESOURCE_QUERY_PARAMS: str = "query_params"
    RESOURCE_PATH_PARAMS: str = "path_params"
    ACTION: str = "action"
    ACTION_GET: str = "GET"
    ACTION_POST: str = "POST"
    ACTION_PUT: str = "PUT"
    ACTION_DELETE: str = "DELETE"
    ACTION_PATCH: str = "PATCH"
    SUBJECT: str = "subject"
    SUBJECT_IS_USER: str = "is_user"
    SUBJECT_IS_SUPERUSER: str = "is_superuser"
    CONTEXT: str = "context"
    CONTEXT_IP_ADDRESS: str = "ip"
    CONTEXT_USER_AGENT: str = "user_agent"
